#############################################################################
#
# MODULE:   	Grass Compilation
# AUTHOR(S):	Original author unknown - probably CERL
#		Markus Neteler - Germany/Italy - neteler@itc.it
#   	    	Justin Hickey - Thailand - jhickey@hpcc.nectec.or.th
#   	    	Huidae Cho - Korea - grass4u@gmail.com
#   	    	Eric G. Miller - egm2@jps.net
# PURPOSE:  	The source file for this Makefile is in src/CMD/head/head.in.
#		It is the top part of a file called make.rules which is used
#		for compiling all GRASS modules. This part of the file provides
#		make variables that are dependent on the results of the
#		configure script.
# COPYRIGHT:    (C) 2000 by the GRASS Development Team
#
#               This program is free software under the GNU General Public
#   	    	License (>=v2). Read the file COPYING that comes with GRASS
#   	    	for details.
#
#############################################################################

############################## Make Variables ###############################

CC                  = /usr/local/src/mxe/usr/bin/x86_64-w64-mingw32.shared-gcc
CXX                 = /usr/local/src/mxe/usr/bin/x86_64-w64-mingw32.shared-g++
LEX                 = flex
YACC                = bison -y
PERL                = /usr/bin/perl
AR                  = /usr/local/src/mxe/usr/bin/x86_64-w64-mingw32.shared-ar
RANLIB              = /usr/local/src/mxe/usr/bin/x86_64-w64-mingw32.shared-ranlib
MKDIR               = mkdir -p
CHMOD               = chmod
INSTALL             = /bin/ginstall -c
INSTALL_DATA        = ${INSTALL} -m 644

prefix              = /usr/local
exec_prefix         = ${prefix}
ARCH                = x86_64-w64-mingw32
UNIX_BIN            = ${exec_prefix}/bin
INST_DIR            = ${prefix}/grass84

GRASS_HOME          = /usr/local/src/grass
RUN_GISBASE         = /usr/local/src/grass/dist.x86_64-w64-mingw32

GRASS_VERSION_MAJOR = 8
GRASS_VERSION_MINOR = 4
GRASS_VERSION_RELEASE = 0dev
GRASS_VERSION_DATE  = 2024
GRASS_VERSION_GIT   = d58b692df8

STRIPFLAG           = 
LD_SEARCH_FLAGS     = 
LD_LIBRARY_PATH_VAR = PATH

#generate static (ST) or shared (SH)
GRASS_LIBRARY_TYPE  = shlib

#static libs:
STLIB_LD            = ${AR} cr
STLIB_PREFIX        = lib
STLIB_SUFFIX        = .a

#shared libs
SHLIB_PREFIX        = lib
SHLIB_LD            = /usr/local/src/mxe/usr/bin/x86_64-w64-mingw32.shared-gcc -shared
SHLIB_LDX           = /usr/local/src/mxe/usr/bin/x86_64-w64-mingw32.shared-g++ -shared
SHLIB_LDFLAGS       = 
SHLIB_CFLAGS        = 
SHLIB_SUFFIX        = .dll
EXE                 = .exe

DEFAULT_DATABASE    =
DEFAULT_LOCATION    =

CPPFLAGS            = 
CFLAGS              = -g -O2 -Wall 
CXXFLAGS            = -g -O2 -Wall
INCLUDE_DIRS        = 
LINK_FLAGS          =   -Wl,--export-dynamic,--enable-runtime-pseudo-reloc

DLLIB               = -ldl
XCFLAGS             = 
XLIBPATH            = 
XLIB                =  
XEXTRALIBS          = 
USE_X11             = 

MATHLIB             = 
ICONVLIB            = -liconv
INTLLIB             = -lintl
SOCKLIB             = 

#ZLIB:
ZLIB                =  -lz 
ZLIBINCPATH         = 
ZLIBLIBPATH         = 

#BZIP2:
BZIP2LIB            =  -lbz2 
BZIP2INCPATH        = 
BZIP2LIBPATH        = 

#ZSTD:
ZSTDLIB             =  -lzstd 
ZSTDINCPATH         = 
ZSTDLIBPATH         = 

DBMIEXTRALIB        = 

#readline
READLINEINCPATH     = 
READLINELIBPATH     = 
READLINELIB         =  -lreadline 
HISTORYLIB          =  -lhistory 

#PostgreSQL:
PQINCPATH           = 
PQLIBPATH           = 
PQLIB               =  -lpq 
USE_POSTGRES        = 1

#MySQL:
MYSQLINCPATH        = 
MYSQLLIBPATH        = 
MYSQLLIB            = 
MYSQLDLIB           = 

#SQLite:
SQLITEINCPATH       = 
SQLITELIBPATH       = 
SQLITELIB           =  -lsqlite3 

#ODBC:
ODBCINC             = 
ODBCLIB             = 

#Image formats:
PNGINC              = -I/usr/include/libpng16
PNGLIB              = -L/usr/lib64 -lpng16 -lm -lz -lm
USE_PNG             = 1

TIFFINCPATH         = 
TIFFLIBPATH         = 
TIFFLIB             =  -ltiff 

#openGL files for NVIZ/r3.showdspf
OPENGLINC           = 
OPENGLLIB           =   -lopengl32 
OPENGLULIB          =   -lglu32 
OPENGL_X11          = 
OPENGL_AQUA         = 
OPENGL_WINDOWS      = 1
USE_OPENGL          = 1

#FFTW:
FFTWINC             = 
FFTWLIB             =  -lfftw3 

#LAPACK/BLAS stuff for gmath lib:
BLASLIB             = -lblas
BLASINC             = 
LAPACKLIB           =  -llapack 
LAPACKINC           = 

#LIBSVM
LIBSVM_LIB          = 
LIBSVM_INC          = 
USE_LIBSVM          = 

#GDAL/OGR
GDALLIBS            = -L/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/lib -lgdal
GDALCFLAGS          = -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include
USE_GDAL            = 1
USE_OGR             = 1

#NetCDF
NETCDFLIBS          = -L/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/lib -lnetcdf -lmfhdf -ldf -lhdf5_hl -lhdf5 -lpthread -lz -lm -lcurl
NETCDFCFLAGS        = -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include
USE_NETCDF          = 1

#LAS LiDAR through libLAS
LASLIBS             = 
LASCFLAGS           = 
LASINC              = 
USE_LIBLAS          = 

#LAS LiDAR through PDAL
PDALLIBS             = 
PDALINC              = 
USE_PDAL             = 

#GEOS
GEOSLIBS            = -L/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/lib -lgeos_c -lgeos -lm -lstdc++ -lgeos_c 
GEOSCFLAGS          = -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include
USE_GEOS            = 1

#FreeType:
FTINC               = -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include/freetype2 -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include/harfbuzz -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include/glib-2.0 -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/lib/glib-2.0/include -mms-bitfields   -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include/freetype2
FTLIB               = -lfreetype   -lfreetype 

#PROJ.4:
PROJINC             = 
PROJLIB             =  -lproj 
PROJSHARE           = /usr/share/proj

#OPENDWG:
OPENDWGINCPATH      = 
OPENDWGLIBPATH      = 
OPENDWGLIB          = 
USE_OPENDWG         = 

#cairo
CAIROINC                  = -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include/cairo -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include/pixman-1 -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include/libpng16  -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include/freetype2 -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include/harfbuzz -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/include/glib-2.0 -I/usr/local/src/mxe/usr/x86_64-w64-mingw32.shared/lib/glib-2.0/include -mms-bitfields  
CAIROLIB                  = -lcairo -lz -lmsimg32 -lgdi32 -lpixman-1  -lfontconfig -lfreetype    
USE_CAIRO                 = 1
CAIRO_HAS_XRENDER         = 
CAIRO_HAS_XRENDER_SURFACE = 

#Python
PYTHON              = python3

#regex
REGEXINCPATH        = 
REGEXLIBPATH        = 
REGEXLIB            =  -lregex 
USE_REGEX           = 1

#pthreads
PTHREADINCPATH      = 
PTHREADLIBPATH      = 
PTHREADLIB          =  
USE_PTHREAD         = 1

#OpenMP
OPENMP_INCPATH      = 
OPENMP_LIBPATH      = 
OPENMP_LIB          =  -lgomp 
OPENMP_CFLAGS       = -fopenmp
USE_OPENMP          = 1

#OpenCL
OCLINCPATH          = 
OCLLIBPATH          = 
OCLLIB              = 
USE_OPENCL          = 

#i18N
HAVE_NLS            = 1

#Large File Support (LFS)
USE_LARGEFILES      = 1
LFS_CFLAGS          = -D_FILE_OFFSET_BITS=64

#BSD sockets
HAVE_SOCKET         = 

MINGW		    = yes
WINDRES		    = /usr/local/src/mxe/usr/bin/x86_64-w64-mingw32.shared-windres
MACOSX_APP	    = 
MACOSX_ARCHS        = 
MACOSX_SDK          = 

# Cross compilation
CROSS_COMPILING     = 1
